Function decoded_len_estimate
fn decoded_len_estimate(encoded_len: usize) -> usize
Returns a conservative estimate of the decoded size of encoded_len base64 symbols (rounded up
to the next group of 3 decoded bytes).
The resulting length will be a safe choice for the size of a decode buffer, but may have up to 2 trailing bytes that won't end up being needed.
Examples
use decoded_len_estimate;
assert_eq!;
assert_eq!;
assert_eq!;
assert_eq!;
// start of the next quad of encoded symbols
assert_eq!;