Function encoded_len

const fn encoded_len(bytes_len: usize, padding: bool) -> Option<usize>

Calculate the base64 encoded length for a given input length, optionally including any appropriate padding bytes.

Returns None if the encoded length can't be represented in usize. This will happen for input lengths in approximately the top quarter of the range of usize.